==========================
DPGEN's documentation
==========================

.. _overview::

.. toctree::
   :maxdepth: 2
   :caption: Overview

   overview/cli
  
  
.. _installation::

.. toctree::
   :maxdepth: 2
   :caption: Installation 


.. _run::

.. toctree::
   :maxdepth: 2
   :caption: Run
   
   run/run-process.rst
   run/param.rst
   run/mdata.rst
   
.. _init::

.. toctree::
   :maxdepth: 2
   :caption: Init   

   init/init-bulk-mdata
   init/init-surf-mdata
   init/init-reaction
   init/init-reaction-jdata
   init/init-reaction-mdata

.. _autotest::

.. toctree::
   :maxdepth: 2
   :caption: Autotest   


.. _simplify::

.. toctree::
   :maxdepth: 2
   :caption: Simplify  

   simplify/simplify-jdata
   simplify/simplify-mdata


.. _tutorial:

.. toctree::
   :maxdepth: 2
   :caption: Tutorial
   :glob:  

   Tutorials <https://tutorials.deepmodeling.com/en/latest/Tutorials/DP-GEN/>


.. _Contribution:

.. toctree::
   :maxdepth: 2
   :caption: Contribution Guide

   README.md
   api/api

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _feedback: 
.. _affiliated packages: 
